## What is Modela?

Modela is a Kubernetes-based automatic machine learning platform that enables you with an expansive API for machine
learning. The system implements Kubernetes custom resources for declaratively managing data, training, inference, and 
infrastructure objects. The Modela control plane manages these resources to provide fully distributed and automated machine learning. 


For a complete documentation of the API, check out the [documentation](https://www.modela.ai/docs/docs).

## Install Modela

Modela can be installed through the Modela CLI, or through Helm Charts. For a complete installation procedure, please 
refer to the installation procedure on the [documentation](https://www.modela.ai/docs/docs/install).

## Using the SDK

The Modela API is implemented by [Modela](https://modela.ai), which can be installed on 
any Kubernetes cluster for free. You can access the API by connecting to the API gateway service hosted by your installation.

